Alexandre Julliard : secur32/tests: Run the tests against the winehq. org server.

Alexandre Julliard julliard at winehq.org
Tue Jul 30 14:14:22 CDT 2013


Module: wine
Branch: master
Commit: 55e37bdbf3b92f509b897991a4cb5649222f94c1
URL:    http://source.winehq.org/git/wine.git/?a=commit;h=55e37bdbf3b92f509b897991a4cb5649222f94c1

Author: Alexandre Julliard <julliard at winehq.org>
Date:   Tue Jul 30 13:01:11 2013 +0200

secur32/tests: Run the tests against the winehq.org server.

---

 dlls/secur32/tests/schannel.c |   12 ++++++------
 1 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/dlls/secur32/tests/schannel.c b/dlls/secur32/tests/schannel.c
index 5076767..0bb07bf 100644
--- a/dlls/secur32/tests/schannel.c
+++ b/dlls/secur32/tests/schannel.c
@@ -513,11 +513,11 @@ static void test_remote_cert(PCCERT_CONTEXT remote_cert)
         cert_cnt++;
     }
 
-    ok(cert_cnt == 2, "cert_cnt = %u\n", cert_cnt);
+    ok(cert_cnt == 3, "cert_cnt = %u\n", cert_cnt);
     ok(incl_remote, "context does not contain cert itself\n");
 }
 
-static const char http_request[] = "HEAD /test.html HTTP/1.1\r\nHost: www.codeweavers.com\r\nConnection: close\r\n\r\n";
+static const char http_request[] = "HEAD /test.html HTTP/1.1\r\nHost: www.winehq.org\r\nConnection: close\r\n\r\n";
 
 static void init_cred(SCHANNEL_CRED *cred)
 {
@@ -639,7 +639,7 @@ static void test_communication(void)
         return;
     }
 
     /* Create a socket and connect to www.codeweavers.com */
     ret = WSAStartup(0x0202, &wsa_data);
     if (ret)
     {
@@ -647,10 +647,10 @@ static void test_communication(void)
         return;
     }
 
-    host = gethostbyname("www.codeweavers.com");
+    host = gethostbyname("www.winehq.org");
     if (!host)
     {
-        skip("Can't resolve www.codeweavers.com\n");
+        skip("Can't resolve www.winehq.org\n");
         return;
     }
 
@@ -667,7 +667,7 @@ static void test_communication(void)
     ret = connect(sock, (struct sockaddr *)&addr, sizeof(addr));
     if (ret == SOCKET_ERROR)
     {
-        skip("Can't connect to www.codeweavers.com\n");
+        skip("Can't connect to www.winehq.org\n");
         return;
     }
 
@@ -639,7 +639,7 @@ static void test_communication(void)
     }
 
-    /* Create a socket and connect to www.codeweavers.com */
+    /* Create a socket and connect to www.winehq.org */
     ret = WSAStartup(0x0202, &wsa_data);
     if (ret)




More information about the wine-cvs mailing list